<no title> — CALCEPH - C language 3.4.1 documentation

    int j;
    int res;
    char nameconstant[CALCEPH_MAX_CONSTANTNAME];
    double valueconstant;
    t_calcephbin *peph;

    /* open the ephemeris file */
    peph = calceph_open("example1.dat");
    if (peph)
    {
       for (j=1; j<=calceph_getconstantcount(peph); j++)
       {
           calceph_getconstantindex(peph, j, nameconstant, &valueconstant);
           printf("'%s'\t= %23.16E\n", nameconstant, valueconstant);
       }

       /* close the ephemeris file */
       calceph_close(peph);
    }